@@ -41,7 +41,13 @@ class SearchAddressBookView(BrowserView):
         # XXX: This should be reviewed and changed to use portal_form_controller
 
         form = self.request.form
-        path = '/'.join(self.context.getPhysicalPath())
+
+        if self.context.meta_type == 'Group':
+            # Means i'm exporting persons from inside a group. I should form
+            # the path from my parent
+            path = '/'.join(self.context.aq_inner.aq_parent.getPhysicalPath())
+        else:
+            path = '/'.join(self.context.getPhysicalPath())
 
         # Here we know if the user requested to export the users
         # the organizations or to send mails to them.
@@ -219,7 +225,6 @@ class SearchAddressBookView(BrowserView):
                  'address' : request.get('address', None),
                  'city' : request.get('city', None),
                  'zip' : request.get('zip', None),
-                 'country' : request.get('country', None),
                  'extra_adress' : request.get('extra_adress', None),
                  'phone' : request.get('phone', None),
                  'fax' : request.get('fax', None),
@@ -231,6 +236,19 @@ class SearchAddressBookView(BrowserView):
                  'text' : request.get('text', None),
                 }
 
+        
+        country = request.get('country', None)
+        if country and country != '--':
+            attrs['country'] = country
+        else:
+            attrs['country'] = None
+
+        state = request.get('state', None)
+        if state and state != '--':
+            attrs['state'] = state
+        else:
+            attrs['state'] = None
+
         all_organizations = [i.getObject() for i in self.portal_catalog(
                                {'portal_type':'Organization',
                                 'path':'/'.join(self.context.getPhysicalPath()),
@@ -299,7 +317,6 @@ class SearchAddressBookView(BrowserView):
                  'work_mobile_phone' : request.get('work_mobile_phone', None),
                  'work_email' : request.get('work_email', None),
                  'address' : request.get('address', None),
-                 'country' : request.get('country', None),
                  'city' : request.get('city', None),
                  'phone' : request.get('phone', None),
                  'mobile_phone' : request.get('mobile_phone', None),
@@ -307,6 +324,18 @@ class SearchAddressBookView(BrowserView):
                  'web' : request.get('web', None),
                  'text' : request.get('text', None),
         }
+        
+        country = request.get('country', None)
+        if country and country != '--':
+            attrs['country'] = country
+        else:
+            attrs['country'] = None
+
+        state = request.get('state', None)
+        if state and state != '--':
+            attrs['state'] = state
+        else:
+            attrs['state'] = None
 
         all_persons = [i.getObject() for i in self.portal_catalog(
                               {'portal_type':'Person',
